<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Recentste controle:</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Als je het bètaprogramma verlaat, ontvang je geen bèta-updates meer.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>Updatelogboek bekijken</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Updategeschiedenis</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Er zijn geen updates geïnstalleerd</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Systeemupdates</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Beveiligingsupdates</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Bevat nieuwe functies, verbeteringen en oplossingen voor beveiligingsproblemen.</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Bevat oplossingen voor beveiligingsproblemen.</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Installatiedatum:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Details bekijken</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Uitgebracht op:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Inklappen</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versie:</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>Updatelogboek</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>Exporteren naar bureaublad</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>GEEN</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>LAAG</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>GEMIDDELD</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>HOOG</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>KRITIEK</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>critical-risk</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>high-risk</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>medium-risk</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>low-risk</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Deze update lost het volgende op:</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>kwetsbaarheden</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>een kwetsbaarheid</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 van %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>Meer informatie:</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Bezig met controleren op updates…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Je beschikt over de nieuwste software</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Onbekende fout</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>De updates kunnen niet worden gedownload. Maak ruimte vrij op %1.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Bijwerken mislukt: afhankelijkheidsfout</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Controleer je internetverbinding en probeer het opnieuw.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>De updates kunnen niet worden gedownload - controleer je internetverbinding.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Er kan geen reservekopie worden gemaakt. Als je doorgaat met de installatie, dan kun je je systeem niet meer herstellen naar een oudere versie.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Als je doorgaat met de installatie, dan kun je je systeem niet meer herstellen naar een oudere versie.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Onvoldoende vrije ruimte</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG-fout</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Bestand ontbreekt</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>Er is een probleem met de updateserver. Controleer je internetverbinding en probeer het opnieuw.</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>De pakketbroninstellingen zijn onjuist. Controleer de instellingen en probeer het opnieuw.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Opnieuw controleren</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Privacybeleid</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Om deze software te kunnen gebruiken, dien je akkoord te gaan met het %1 omtrent software-updates.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Schakel de opties onder ‘Update-inhoud’ in om de gebruikservaring te verbeteren</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Er kan geen verbinding worden gemaakt, omdat je systeem niet is geactiveerd.</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Systeemupdates zijn uitgeschakeld. Neem contact op met je systeembeheerder.</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>Automatisch herstel is ingeschakeld - updates zijn hierdoor niet mogelijk. Neem contact op met de systeembeheerder.</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>De updates zijn gedownload. Welke actie wil je uitvoeren?</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>Stille installatie</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Bijwerken en herstarten</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Bijwerken en afsluiten</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Slimme spiegelserverwisselaar</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Soort updates</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Functionele updates</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Bevat nieuwe functies, verbeteringen en oplossingen voor beveiligingsproblemen.</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Beveiligingsupdates</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Bevat oplossingen voor beveiligingsproblemen.</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Externe updates</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Bevat updates uit aanvullende pakketbronnen.</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Snelheid beperken</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Beperken tot</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Automatisch downloaden</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Schakel deze optie in om updates automatisch te downloaden zodra er een internetverbinding is.</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Downloaden tijdens inactiviteit</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Beginnen om</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Eindigen om</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Geavanceerde instellingen</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Updatemeldingen tonen</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Pakketcache legen</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Updategeschiedenis</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Intern testkanaal inschakelen</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Klik hier om te voltooien</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Uitklappen</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>Forumgebruikers met niveau 2 of hoger kunnen deelnemen aan de bètatest.</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Inklappen</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>Alleen getallen tussen de 1 en 99999 zijn toegestaan</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Systeemupdates</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Er zijn enkele gemelde bugs en beveiligingsproblemen opgelost</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Beveiligingsupdates</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Externe pakketbronnen</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>updatelogboek</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Exporteren mislukt - probeer het opnieuw</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Het logboek is opgeslagen op het bureaublad</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Bijwerken</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Systeemupdates</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Systeemupdates en -upgrades</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Update-instellingen</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Bezig met installeren</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Het downloaden is voltooid</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Updates installeren</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Updategrootte:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Het downloaden is mislukt</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Bezig met downloaden…</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Bezig met downloaden</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Stel de update-instellingen in, evenals beveiligingsupdates, automatisch downloaden en meldingen</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Nu herstarten</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Bezig met installeren…</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Opnieuw proberen</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Doorgaan met updates</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Updates beschikbaar</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>De installatie is mislukt</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Herstart nadien je computer om alle wijzigingen toe te passen.</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Bezig met maken van reserviekopie…</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Bezig met maken van reserviekopie</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Reservekopie mislukt</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>De updates zijn geïnstalleerd</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Als je doorgaat met de installatie, dan kun je je systeem niet meer herstellen naar een oudere versie.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Opnieuw proberen</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Doorgaan met bijwerken</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>Het accuniveau is lager dan 60%. Sluit de stroomkabel aan om de updates te installeren.</translation>
    </message>
</context>
</TS>